function cbs = cbs_create(tmin, tmax, npts, valdim)
%cbs_create Create a cubic monodimensional B-spline.
%
% cbs = cbs_create(tmin, tmax, npts, valdim)
%
% Create a structure containing the parameters of a monodimensional cubic
% B-Spline. It can be mono or multi valued depending on the "valdim"
% parameter.
%
% INPUT ARGUMENTS
%
%   tmin, tmax [scalars]: limits of the domain of definition. By 
%   convention, the letter t is used for the input space of the spline 
%   while the letters (x,y,...) are used for the output space.
%
%   npts [scalar]: number of control points. The total number of parameters
%   is valdim*npts.
%
%   valdim [scalar]: dimension of the B-Spline values. "valdim=1"
%   correspond to a monovalued spline (function R->R). "valdim=2"
%   corresponds to a parametric spline in the plane (function R->R^2).
%
% OUTPUT ARGUMENTS
%
%   cbs [structure]: a structure containing the parameters of the spline.
%   Note that this structure does not contains the control points of the
%   spline.
%
% NOTE
%  CBS is partly based on the original source code of BBS.
%
% (c)2011, Florent Brunet.

% This file is part of CBS.
%
% CBS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% CBS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with CBS.  If not, see <http://www.gnu.org/licenses/>.

if npts < 4
    error('bsw:numberOfCtrlPts', 'The number of control point must be > 4.');
end

cbs.tmin = tmin;
cbs.tmax = tmax;
cbs.npts = npts;
cbs.valdim = valdim;
